@@ -8,9 +8,9 @@ class MarkovChain(object):
     def __init__(self, dbFilePath=None):
         self.dbFilePath = dbFilePath
         if not dbFilePath:
-            dbFilePath = os.path.join(os.path.dirname(__file__), "markovdb")
+            self.dbFilePath = os.path.join(os.path.dirname(__file__), "markovdb")
         try:
-            with open(dbFilePath, 'rb') as dbfile:
+            with open(self.dbFilePath, 'rb') as dbfile:
                 self.db = pickle.load(dbfile)
         except IOError:
             print('Database file not found, using empty database\n')
